//////////////////////////////////////////////////////////////
// install.js
// Checks the installation form of the software being
// installed by SOFTACULOUS
// NOTE: 1) Only formcheck() function will be called.
//       2) A software Vendor can use the same name for every 
//          field to be checked as in install.xml . It can be
//          called using $('fieldname').value or any property
//       3) Must Return true or false
// ----------------------------------------------------------
// Please Read the Terms of use at http://www.softaculous.com
// ----------------------------------------------------------
// (c)Softaculous Inc.
//////////////////////////////////////////////////////////////

function formcheck(){
	
	//Check the Admin Email
	if(window.check_punycode){
		if(!check_punycode($('admin_email').value)){
			alert('{{err_ademail}}');
			return false;
		}
		return true;
	}
	
	return true;
};


jQuery(document).ready(function(){
	
	var domain = jQuery("#softdomain").val();
	jQuery("#in_host_server").val("imap."+domain);
	jQuery("#out_host_server").val("smtp."+domain);
	
	jQuery("#softdomain").change(function(){
		var domain = jQuery(this).val();
		jQuery("#in_host_server").val("imap."+domain);
		jQuery("#out_host_server").val("smtp."+domain);
	});
	
	//alert("imap."+domain);
	
});

// Update the in dir
function update_webmail_indir(){
	
	if(webmail_retries >= 5){
		return;
	}
	
	if(typeof jQuery('#softdirectory').val() == "undefined"){
		webmail_retries++;
		setTimeout('update_webmail_indir();', 500);
		return;
	}
	
	var softdirectory = jQuery('#softdirectory').val();
	
	if(softdirectory == 'webmail'){
		jQuery('#softdirectory').val('mywebmail');
	}
}

var webmail_retries = 0;
update_webmail_indir();

jQuery(document).ready(function(){
	
	// Joomla requires password to be minimum 12 chars so generate random accordingly
	if(globals_rand_pass > 0){
		setTimeout('webmail_rand_pass();', 500);
	}

	jQuery( ".generate-password" ).on( "click", function(){
		webmail_rand_pass();
	});
	
});

function webmail_rand_pass(){
	
	try{
		jQuery("#admin_pass").val(randstr(12, 1, globals_pass_strength));
		check_pass_strength();
	}
	catch(e){}
}